==> org.wso2.micro.gateway.cli-2.5.0-sources.jar: org/wso2/apimgt/gateway/cli/constants/TokenManagementConstants.java <==
/*
 *  Copyright (c) 2018, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.wso2.apimgt.gateway.cli.constants;

public class TokenManagementConstants {
    public static final String CALLBACK_URL = "callbackUrl";
    public static final String CLIENT_NAME = "clientName";
    public static final String TOKEN_SCOPE = "tokenScope";
    public static final String TOKEN_SCOPE_PRODUCTION = "PRODUCTION";
    public static final String OWNER = "owner";
    public static final String SAAS_APP = "saasApp";
    public static final String GRANT_TYPE = "grantType";
    public static final String APPLICATION_NAME = "Micro Gateway Cli";
    public static final String APPLICATION_CALLBACK_URL = "https://wso2.org";
    public static final String POLICY_VIEW_TOKEN_SCOPE = "apim:tier_view";
    public static final String VIEW_API_SCOPE = "apim:api_view";
    public static final String PASSWORD_GRANT_TYPE = "password";
    public static final String CONTENT_TYPE = "Content-Type";
    public static final String CONTENT_TYPE_APPLICATION_JSON = "application/json";
    public static final String POST = "POST";
    public static final String AUTHORIZATION = "Authorization";
    public static final String BASIC = "Basic";
    public static final String UTF_8 = "UTF-8";
    public static final String CLIENT_ID = "clientId";
    public static final String CLIENT_SECRET = "clientSecret";
    public static final String CONTENT_TYPE_APPLICATION_X_WWW_FORM_URLENCODED = "application/x-www-form-urlencoded";
    public static final String PASSWORD = "password";
    public static final String ACCESS_TOKEN = "access_token";
}

==> org.wso2.micro.gateway.cli-3.2.9-sources.jar: org/wso2/apimgt/gateway/cli/constants/TokenManagementConstants.java <==
/*
 *  Copyright (c) 2018, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.wso2.apimgt.gateway.cli.constants;

/**
 * Constants used by the API token management utilities.
 */
public class TokenManagementConstants {
    public static final String CALLBACK_URL = "callbackUrl";
    public static final String CLIENT_NAME = "clientName";
    public static final String TOKEN_SCOPE = "tokenScope";
    public static final String TOKEN_SCOPE_PRODUCTION = "PRODUCTION";
    public static final String OWNER = "owner";
    public static final String SAAS_APP = "saasApp";
    public static final String GRANT_TYPE = "grantType";
    public static final String APPLICATION_NAME = "Micro_Gateway_Cli";
    public static final String APPLICATION_CALLBACK_URL = "https://wso2.org";
    public static final String POLICY_VIEW_TOKEN_SCOPE = "apim:tier_view";
    public static final String VIEW_API_SCOPE = "apim:api_view";
    public static final String PASSWORD_GRANT_TYPE = "password";
    public static final String CONTENT_TYPE = "Content-Type";
    public static final String CONTENT_TYPE_APPLICATION_JSON = "application/json";
    public static final String POST = "POST";
    public static final String AUTHORIZATION = "Authorization";
    public static final String BASIC = "Basic";
    public static final String UTF_8 = "UTF-8";
    public static final String CLIENT_ID = "clientId";
    public static final String CLIENT_SECRET = "clientSecret";
    public static final String CONTENT_TYPE_APPLICATION_X_WWW_FORM_URLENCODED = "application/x-www-form-urlencoded";
    public static final String PASSWORD = "password";
    public static final String ACCESS_TOKEN = "access_token";
    public static final String TLS = "TLS";
}
